==> j2sdk-1_4_2_03-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "*" },
        { "FileChooser.cancelButtonText", "Cancel" },
        { "FileChooser.cancelButtonToolTipText", "Abort file chooser dialog." },
        { "FileChooser.deleteFileButtonText", "Delete File" },
        { "FileChooser.filesLabelText", "Files" },
        { "FileChooser.foldersLabelText", "Folders" },
        { "FileChooser.newFolderButtonText", "New Folder" },
        { "FileChooser.openButtonText", "OK" },
        { "FileChooser.openButtonToolTipText", "Open selected file." },
        { "FileChooser.openDialogTitleText", "Open" },
        { "FileChooser.pathLabelText", "Selection:" },
        { "FileChooser.renameFileButtonText", "Rename File" },
        { "FileChooser.saveButtonText", "Save" },
        { "FileChooser.saveButtonToolTipText", "Save selected file." },
        { "FileChooser.saveDialogTitleText", "Save" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "Blue:" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "Color Name:" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "Green:" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "Hue:" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK Color Chooser" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "Red:" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "Saturation:" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "Value:" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}

==> j2sdk-1_5_0_01-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "All Files" },
        { "FileChooser.cancelButtonText", "Cancel" },
        { "FileChooser.cancelButtonToolTipText", "Abort file chooser dialog." },
        { "FileChooser.deleteFileButtonText", "Delete File" },
        { "FileChooser.filesLabelText", "Files" },
        { "FileChooser.filterLabelText", "Filter:" },
        { "FileChooser.foldersLabelText", "Folders" },
        { "FileChooser.newFolderButtonText", "New Folder" },
        { "FileChooser.newFolderDialogText", "Folder name:" },
        { "FileChooser.openButtonText", "OK" },
        { "FileChooser.openButtonToolTipText", "Open selected file." },
        { "FileChooser.openDialogTitleText", "Open" },
        { "FileChooser.pathLabelText", "Selection:" },
        { "FileChooser.renameFileButtonText", "Rename File" },
        { "FileChooser.renameFileDialogText", "Rename file \"{0}\" to" },
        { "FileChooser.renameFileErrorText", "Error renaming file \"{0}\" to \"{1}\"" },
        { "FileChooser.renameFileErrorTitle", "Error " },
        { "FileChooser.saveButtonText", "Save" },
        { "FileChooser.saveButtonToolTipText", "Save selected file." },
        { "FileChooser.saveDialogTitleText", "Save" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "Blue:" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "Color Name:" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "Green:" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "Hue:" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK Color Chooser" },
        { "GTKColorChooserPanel.redMnemonic", "69" },
        { "GTKColorChooserPanel.redText", "Red:" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "Saturation:" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "Value:" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}
